@@ -2,7 +2,7 @@ package Bio::Graphics::Glyph::diamond;
 # DAS-compatible package to use for drawing a colored diamond
 
 use strict;
-use base qw(Bio::Graphics::Glyph::generic);
+use base qw(Bio::Graphics::Glyph::point_glyph);
 
 sub my_description {
     return <<END;
@@ -70,6 +70,7 @@ sub draw_component {
   }
 }
 
+
 1;
 
 __END__
